===============================================
openxc - Python Library for the OpenXC Platform
===============================================

.. image:: /_static/logo.png

:Version: 0.10.0
:Web: http://openxcplatform.com
:Download: http://pypi.python.org/pypi/openxc/
:Documentation: http://python.openxcplatform.com
:Source: http://github.com/openxc/openxc-python/
:Keywords: vehicle, openxc, python

--

The OpenXC Python library (for Python 2.6 or 2.7 - not 3.x until the protobuf
library is updated) provides an alternative interface to vehicle data from the
OpenXC Platform. The primary platform for OpenXC applications is Android, but
for prototyping and testing, often it is preferrable to use a low-overhead
environment like Python when developing.

In addition to a port of the Android library API, the package also contains a
number of command-line tools for connecting to the CAN translator and
manipulating previously recorded vehicle data.

License
=======

Copyright (c) 2012-2013 Ford Motor Company

Licensed under the BSD license.
